@@ -3,7 +3,7 @@
  *  Copyright (c) 2002, 2007 Sam Hocevar <sam@zoy.org>
  *                All Rights Reserved
  *
- *  $Id: zzuf.c 309 2007-11-02 22:45:54Z sam $
+ *  $Id$
  *
  *  This program is free software. It comes without any warranty, to
  *  the extent permitted by applicable law. You can redistribute it
@@ -168,7 +168,7 @@ int main(int argc, char *argv[])
 #else
 #   define OPTSTR_RLIMIT_CPU ""
 #endif
-#define OPTSTR OPTSTR_REGEX OPTSTR_RLIMIT_MEM OPTSTR_RLIMIT_CPU \
+#define OPTSTR "+" OPTSTR_REGEX OPTSTR_RLIMIT_MEM OPTSTR_RLIMIT_CPU \
                 "Ab:B:C:dD:f:F:il:mnp:P:qr:R:s:St:vxhV"
 #define MOREINFO "Try `%s --help' for more information.\n"
         int option_index = 0;
@@ -452,7 +452,7 @@ int main(int argc, char *argv[])
     /* Clean up */
     _zz_opts_fini(opts);
 
-    return opts->crashes ? EXIT_FAILURE : EXIT_SUCCESS;    
+    return opts->crashes ? EXIT_FAILURE : EXIT_SUCCESS;
 }
 
 static void loop_stdin(struct opts *opts)
@@ -639,7 +639,7 @@ static void spawn_children(struct opts *opts)
     if(opts->verbose)
     {
         finfo(stderr, opts, opts->child[i].seed);
-        fprintf(stderr, "launched %s\n", opts->newargv[0]);
+        fprintf(stderr, "launched `%s'\n", opts->newargv[0]);
     }
 
     opts->lastlaunch = now;
@@ -1010,7 +1010,7 @@ static int run_process(struct opts *opts, int pipes[][2])
     epaddr = get_entry(opts->newargv[0]);
     if(!epaddr)
         return -1;
-    
+
     memset(&sinfo, 0, sizeof(sinfo));
     sinfo.cb = sizeof(sinfo);
     DuplicateHandle(pid, (HANDLE)_get_osfhandle(pipes[0][1]), pid,
@@ -1140,8 +1140,8 @@ static void *get_entry(char const *name)
 
 static void version(void)
 {
-    printf("zzuf %s\n", VERSION);
-    printf("Copyright (C) 2002, 2007 Sam Hocevar <sam@zoy.org>\n");
+    printf("zzuf %s\n", PACKAGE_VERSION);
+    printf("Copyright (C) 2002, 2007-2008 Sam Hocevar <sam@zoy.org>\n");
     printf("This is free software.  You may redistribute copies of it under the\n");
     printf("terms of the Do What The Fuck You Want To Public License, Version 2\n");
     printf("<http://sam.zoy.org/wtfpl/>.\n");
